==> mylibrary-4.0.1-1-x86_64.pkg.tar.zst: usr/share/doc/MLBookProc/html/hierarchy.js <==
var hierarchy =
[
    [ "AddBook", "classAddBook.html", null ],
    [ "ArchEntry", "classArchEntry.html", null ],
    [ "ArchiveFileEntry", "classArchiveFileEntry.html", null ],
    [ "ArchiveRemoveEntry", "classArchiveRemoveEntry.html", null ],
    [ "AuxFunc", "classAuxFunc.html", null ],
    [ "BaseKeeper", "classBaseKeeper.html", null ],
    [ "BookBaseEntry", "classBookBaseEntry.html", null ],
    [ "BookInfo", "classBookInfo.html", null ],
    [ "BookInfoEntry", "classBookInfoEntry.html", null ],
    [ "BookMarks", "classBookMarks.html", null ],
    [ "BookParseEntry", "classBookParseEntry.html", null ],
    [ "ByteOrder", "classByteOrder.html", null ],
    [ "DJVUParser", "classDJVUParser.html", null ],
    [ "ElectroBookInfoEntry", "classElectroBookInfoEntry.html", null ],
    [ "FileParseEntry", "classFileParseEntry.html", null ],
    [ "Genre", "classGenre.html", null ],
    [ "GenreGroup", "classGenreGroup.html", null ],
    [ "Hasher", "classHasher.html", [
      [ "CreateCollection", "classCreateCollection.html", [
        [ "RefreshCollection", "classRefreshCollection.html", null ]
      ] ]
    ] ],
    [ "LibArchive", "classLibArchive.html", [
      [ "ARCHParser", "classARCHParser.html", null ],
      [ "EPUBParser", "classEPUBParser.html", null ]
    ] ],
    [ "MLException", "classMLException.html", null ],
    [ "NotesBaseEntry", "classNotesBaseEntry.html", null ],
    [ "NotesKeeper", "classNotesKeeper.html", null ],
    [ "OmpLockGuard", "classOmpLockGuard.html", null ],
    [ "OpenBook", "classOpenBook.html", null ],
    [ "PaperBookInfoEntry", "classPaperBookInfoEntry.html", null ],
    [ "PDFParser", "classPDFParser.html", null ],
    [ "RemoveBook", "classRemoveBook.html", null ],
    [ "ReplaceTagItem", "classReplaceTagItem.html", null ],
    [ "SelfRemovingPath", "classSelfRemovingPath.html", null ],
    [ "XMLParser", "classXMLParser.html", [
      [ "EPUBParser", "classEPUBParser.html", null ],
      [ "FB2Parser", "classFB2Parser.html", null ],
      [ "FormatAnnotation", "classFormatAnnotation.html", null ]
    ] ],
    [ "XMLTag", "classXMLTag.html", null ]
];

==> mylibrary-4.1-1-x86_64.pkg.tar.zst: usr/share/doc/MLBookProc/html/hierarchy.js <==
var hierarchy =
[
    [ "AddBook", "classAddBook.html", null ],
    [ "ArchEntry", "classArchEntry.html", null ],
    [ "ArchiveFileEntry", "classArchiveFileEntry.html", null ],
    [ "ArchiveRemoveEntry", "classArchiveRemoveEntry.html", null ],
    [ "AuxFunc", "classAuxFunc.html", null ],
    [ "BaseKeeper", "classBaseKeeper.html", null ],
    [ "BookBaseEntry", "classBookBaseEntry.html", null ],
    [ "BookInfo", "classBookInfo.html", null ],
    [ "BookInfoEntry", "classBookInfoEntry.html", null ],
    [ "BookMarks", "classBookMarks.html", null ],
    [ "BookParseEntry", "classBookParseEntry.html", null ],
    [ "ByteOrder", "classByteOrder.html", null ],
    [ "DJVUParser", "classDJVUParser.html", null ],
    [ "ElectroBookInfoEntry", "classElectroBookInfoEntry.html", null ],
    [ "FileParseEntry", "classFileParseEntry.html", null ],
    [ "Genre", "classGenre.html", null ],
    [ "GenreGroup", "classGenreGroup.html", null ],
    [ "Hasher", "classHasher.html", [
      [ "CreateCollection", "classCreateCollection.html", [
        [ "RefreshCollection", "classRefreshCollection.html", null ]
      ] ]
    ] ],
    [ "LibArchive", "classLibArchive.html", [
      [ "ARCHParser", "classARCHParser.html", null ],
      [ "EPUBParser", "classEPUBParser.html", null ],
      [ "ODTParser", "classODTParser.html", null ]
    ] ],
    [ "MLException", "classMLException.html", null ],
    [ "NotesBaseEntry", "classNotesBaseEntry.html", null ],
    [ "NotesKeeper", "classNotesKeeper.html", null ],
    [ "OmpLockGuard", "classOmpLockGuard.html", null ],
    [ "OpenBook", "classOpenBook.html", null ],
    [ "PaperBookInfoEntry", "classPaperBookInfoEntry.html", null ],
    [ "PDFParser", "classPDFParser.html", null ],
    [ "RemoveBook", "classRemoveBook.html", null ],
    [ "ReplaceTagItem", "classReplaceTagItem.html", null ],
    [ "SelfRemovingPath", "classSelfRemovingPath.html", null ],
    [ "XMLParser", "classXMLParser.html", [
      [ "DCParser", "classDCParser.html", null ],
      [ "EPUBParser", "classEPUBParser.html", null ],
      [ "FB2Parser", "classFB2Parser.html", null ],
      [ "FormatAnnotation", "classFormatAnnotation.html", null ],
      [ "ODTParser", "classODTParser.html", null ]
    ] ],
    [ "XMLTag", "classXMLTag.html", null ]
];
